@@ -30,15 +30,6 @@ def m2m(db, table1, table2):
     )
 
 
-def _merge_mapper_args(cls):
-    classes = (cls,) + cls.__bases__
-    mapper_args = {}  
-    for c in classes:
-        if hasattr(c, '__mapper_args__'):
-            mapper_args.update(c.__mapper_args__)
-    return mapper_args
-
-
 class UUID(types.TypeDecorator):
 
     impl = types.String
@@ -58,17 +49,13 @@ class JoinedInheritanceMixin:
 
     @declared_attr
     def __mapper_args__(cls):
-        print('mapper_args from JoinedInheritanceMixin')
-        
-        
+
         indentity = cls.__name__.lower()
         mapper_args = {'polymorphic_identity': indentity}
 
         if JoinedInheritanceMixin in cls.__bases__:
             mapper_args.update({'polymorphic_on': cls._model_type})
 
-        mapper_args.update(_merge_mapper_args(cls))
-
         return mapper_args
 
 
@@ -86,28 +73,25 @@ class ModelUUID(SAModel):
         return Column(*args, **kwargs)
 
     @declared_attr
-    def created_at(cls):        
+    def created_at(cls):
         return Column(DateTime, default=datetime.now, nullable=False, index=True)
 
     @declared_attr
     def __mapper_args__(cls):
-        print('mapper_args from ModelUUID')
-
-        mapper_args = {
+        mapper = {
             'order_by': cls.created_at
         }
-
-        # mapper_args.update(_merge_mapper_args(cls))
-        
-        return mapper_args
-
+        classes = (cls,) + cls.__bases__
+        for c in classes:
+            if hasattr(c, '__mapper_args__'):
+                mapper.update(c.__mapper_args__)
+        return mapper
 
 
 class Query(BaseQuery):
 
     @property
     def non_deleted(self):
-
         return self.filter_by(deleted=False)
 
 
@@ -119,6 +103,6 @@ class SQLAlchemyDRY(_SQLAlchemy):
         super(SQLAlchemyDRY, self).__init__(*args, **kwargs)
 
         self.UUID = UUID
-        
+
     def m2m(self, t1, t2):
         return m2m(self, t1, t2)
\ No newline at end of file
